@@ -34,6 +34,7 @@ class SolutionStateManager:
     }
 
     required_new_job_fields = [
+        "TrainingJobName",
         'AlgorithmSpecification',
         'HyperParameters'
         'InputDataConfig'
@@ -67,7 +68,7 @@ class SolutionStateManager:
 
         new_training_job = {}
         for key_, values_ in prev_training_job.items():
-            if key_ not in self.required_new_job_fields:
+            if key_ in self.required_new_job_fields:
                 new_training_job.update({
                     key_ : values_
                 })
