@@ -65,7 +65,7 @@ class RecommendationsManager:
             client_id: id,
             item_id: str,
             engine: str,
-            context: dict = {},
+            context: dict = None,
             **kwargs
     ):
         """
@@ -125,6 +125,7 @@ class RecommendationsManager:
 
         # write to lambda output logs
         print(json.dumps(trigger_log))
+        print(results)
         return results
 
     def get_client(
@@ -179,13 +180,16 @@ class RecommendationsManager:
         """
         campaign_kwargs = {'recipe': recipe}
 
-        return self.query_helper.get_campaign(
+        campaign, _ = self.query_helper.get_campaign(
             client_id=client_id,
             service_id=self.service.id,
             engine_slug=engine,
+            from_cache=True,
             **campaign_kwargs
         )
 
+        return campaign
+
     def encode_item_code(
             self,
             *,
@@ -204,9 +208,9 @@ class RecommendationsManager:
 
         item_codes = []
 
-        cache_key = self.query_helper.build_cache_key(
+        cache_key = self.query_helper.create_resource_name(
             service=self.service.name,
-            obj_group=self.item_code_identifier,
+            group=self.item_code_identifier,
             prefix=[self.engine, self.client.name]
         )
 
@@ -259,9 +263,9 @@ class RecommendationsManager:
         """
         item_ids = []
 
-        cache_key = self.query_helper.build_cache_key(
+        cache_key = self.query_helper.create_resource_name(
             service=self.service.name,
-            obj_group=self.item_id_identifier,
+            group=self.item_id_identifier,
             prefix=[self.engine, self.client.name]
         )
 
